@@ -14,7 +14,7 @@ use std::collections::HashMap;
 use std::future::Future;
 
 #[cfg(doc)]
-use perspective_client::{Schema, TableInitOptions, UpdateOptions, config::ViewConfigUpdate};
+use perspective_client::{TableInitOptions, UpdateOptions, config::ViewConfigUpdate};
 use perspective_client::{assert_table_api, assert_view_api};
 use pyo3::exceptions::PyTypeError;
 use pyo3::marker::Ungil;
@@ -194,6 +194,13 @@ impl Client {
             .py_block_on(py)
     }
 
+    /// Provides the [`SystemInfo`] struct, implementation-specific metadata
+    /// about the [`perspective_server::Server`] runtime such as Memory and
+    /// CPU usage.
+    pub fn system_info(&self, py: Python<'_>) -> PyResult<Py<PyAny>> {
+        self.0.system_info().py_block_on(py)
+    }
+
     /// Terminates this [`Client`], cleaning up any [`View`] handles the
     /// [`Client`] has open as well as its callbacks.
     pub fn terminate(&self, py: Python<'_>) -> PyResult<()> {
@@ -201,6 +208,19 @@ impl Client {
     }
 }
 
+/// [`Table`] is Perspective's columnar data frame, analogous to a Pandas/Polars
+/// `DataFrame` or Apache Arrow, supporting append & in-place updates, removal
+/// by index, and update notifications.
+///
+/// A [`Table`] contains columns, each of which have a unique name, are strongly
+/// and consistently typed, and contains rows of data conforming to the column's
+/// type. Each column in a [`Table`] must have the same number of rows, though
+/// not every row must contain data; null-values are used to indicate missing
+/// values in the dataset. The schema of a [`Table`] is _immutable after
+/// creation_, which means the column names and data types cannot be changed
+/// after the [`Table`] has been created. Columns cannot be added or deleted
+/// after creation either, but a [`View`] can be used to select an arbitrary set
+/// of columns from the [`Table`].
 #[pyclass(subclass, name = "Table", module = "perspective")]
 pub struct Table(AsyncTable);
 
